#!/usr/bin/perl
#========================================================================
# ExSite::Mail  --  miscellaneous E-Mail functions
# Author: Alan Douglas, Exware Solutions, April 2003
#========================================================================
#
#   Copyright 2001-2004 Exware Solutions, Inc.  http://www.exware.com
#
#   This file is part of ExSite WebWare (ExSite, for short).
#
#   ExSite is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   ExSite is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with ExSite; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Users requiring warranty coverage and/or support may arrange alternate
#   commercial licensing for ExSite, by contacting Exware Solutions 
#   via the website noted above.
#
#----------------------------------------------------------------------------


######## kludge version: should have alternate mailers, with a generic
######## wrapper routine.  Choice of mailer should be a config option.


package ExSite::Mail;

use ExSite::Config;
use Net::SMTP;
use strict;

BEGIN {
    use Exporter   ();
    use vars       qw($VERSION @ISA @EXPORT);
    $VERSION     = 1.00;
    @ISA         = qw(Exporter);
    @EXPORT = qw(   &SendMail
		    );
}

my $sendmailpath = "/usr/lib/sendmail";

sub SendMail {
   return SendMail_1(@_);
}


sub SendMail_1{
   my ($to,$from,$subject,$body) = @_;
   my @lines;
   return 2 if ($to !~ /\w/);
 
   my $smtp = new Net::SMTP('localhost');
   $smtp->mail($from);
   # 20040416 MB - allow for multiple recipients
   my @to = split(/,/,$to);
   $smtp->to(@to);
   $smtp->data;
   $smtp->datasend("To: $to\nFrom: $from\nSubject: $subject\n\n");
   @lines=split(/\n/,$body);
   foreach (@lines) {
      $_ =~ s/"/\\"/g;
      $_ =~ s/\n//g;
      $_ =~ s/\r//g;
      $smtp->datasend("$_\n");
   }
   $smtp->dataend;
   $smtp->quit;
   return 0;
}

#--------------------------------------------------------------------
# SendMail : sends an email using a template
#
# INPUT:
#    1) to: address
#    2) from: address
#    3) subject string
#    4) template for email body
#    5) datahash for subsitution into template
#
# OUTPUT:
#    0 for success; !0 for failure
#--------------------------------------------------------------------

sub SendMail_2 {
    my ($to,$from,$subject,$template,%data) = @_;
    
    if (!open (SENDMAIL, "|$sendmailpath -t")) {
	return 1;
    }
    else {
	my $do;
        print SENDMAIL "To: $to\nFrom: $from\nSubject: $subject\n\n";
	open F,"<$config{server}->{HTMLroot}$config{server}->{HTMLpath}/templates/emails/$template" or return 2;
	my @lines = <F>;
	close F;
	foreach (@lines) {
	    $_ =~ s/"/\\"/g;
	    $do = "print SENDMAIL \"$_\"";
	    eval $do;  # performs variable substitutions in template
	}
        close SENDMAIL;
	return 0;
    }
}

sub SendMail_3 {
#----------------------------------------------------------------------
# SimpleSendMail: a simplified version of the webdb SendMail function.
#                 It has also been adjusted to allow sending even from
#                 badly misconfigured mail servers
#
# Arguments:
#   to      - recipient email address
#   from    - sender email address
#   subject - email subject header
#   message - message body
#
# Returns 0 if it worked 
#         1 if not

    my ($to,$from,$subject,$message) = @_;
	
    if (!open (SENDMAIL, "|$sendmailpath -f $from $to")) {
        return 1;
    }
    else {
        print SENDMAIL "To: $to\nFrom: $from\nSubject: $subject\n\n$message";
        close SENDMAIL;
        return 0;
    }
}


1;
