package Modules::PhotoAlbum;

#----------------------------------------------------------------------------
#
#   Copyright 2001-2004 Exware Solutions, Inc.  http://www.exware.com
#
#   This file is part of ExSite WebWare (ExSite, for short).
#
#   ExSite is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   ExSite is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with ExSite; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Users requiring warranty coverage and/or support may arrange alternate
#   commercial licensing for ExSite, by contacting Exware Solutions 
#   via the website noted above.
#
#-----------------------------------------------------------------------
# PhotoAlbum : tool to browse a library
#
# This module provides a simple example of how to use a dynamic content
# driver to provide alternative interfaces to the ExSite CMS.
#
# To make a photo album:
#   - create a library under your website, using the Website Editor
#   - create a content object for each photo
#   - the content description will be used as a photo caption
#   - the latest version of the content will be displayed as the photo
#-----------------------------------------------------------------------

use strict;
use ExSite::Config;
use ExSite::Input;
use ExSite::Content;
use Modules::BaseDCD;

# inherit basic behaviours from BaseDCD

use vars qw(@ISA);
@ISA = qw(Modules::BaseDCD);

# provide our own write() method

sub write {
    my ($this,$options) = @_;
    my $in = new ExSite::Input;
    my $q = $in->query;
    my $db = $share{DB};
    my ($next, $curr, $prev);
    my ($album,$album_id);
    if ($options =~ /^d+$/) {
	# album passed by id#
	$album_id = $options;
	$album = $db->fetch("page",$album_id);
    }
    else {
	# album passed by name
        my @lib = $db->fetch_match("page",{section_id=>$share{Page}->id("section"),
                                           filename=>$options});
	#my @lib = $db->fetch_match("page",{filename=>$options});
	$album = $lib[0];
	$album_id = $album->{page_id};
    }
    if (!$album) {
	# look for "images" library in current site
	#### TODO

    }
    if ($album) {
	
	my @pics = $db->fetch_child("content","page",
				    $album_id,"name");
	$curr = $q->{cid} || 0;
	if ($curr > $#pics || $curr < 0) { $curr = 0; }
	$next = $curr < $#pics ? $curr + 1 : 0;
	$prev = $curr > 0 ? $curr - 1 : $#pics;
	
	my $c = new ExSite::Content(content=>$pics[$curr]);
	
	my $out = "<h1>$album->{title}</h1>\n";
	$out .= "<table width=\"200\" cellspacing=\"6\" border=\"0\"><tr><td align=\"center\" colspan=\"3\"><p>$album->{description}</p></td></tr>\n<tr><td align=\"center\" colspan=\"3\">";
	$out .= $c->get_html("border=\"1\"");
	$out .= "</td></tr>\n<tr><td align=\"center\" colspan=\"3\"><span class=\"caption\">$pics[$curr]->{description}</span></td></tr>\n<tr><td align=\"left\" width=\"33%\">";
	if ($prev < $curr) {
	    my $prevurl = $this->relink(cid=>$prev);
	    $out .= "&lt;&lt; <a href=$prevurl>previous</a>";
	}
	$out .= "</td><td align=\"center\" width=\"33%\">\n";
	if ($curr > 0) {
	    my $url = $this->relink(cid=>undef);
	    $out .= "<a href=$url>back to start</a>";
	}
	$out .= "</td><td align=\"right\" width=\"33%\">";
	if ($next > $curr) {
	    my $nexturl = $this->relink(cid=>$next);
	    $out .= "<a href=$nexturl>next</a> &gt;&gt;";
	}
	$out .= "</td></tr></table>\n"; 
	return $out;
    }
    else {
	my $message = "library $options not found";
	$this->error($message);
	return "<p class=\"error\">$message</p>\n";
    }
}

sub ioctl {
    my $this = shift;
    $_ = shift;
    if (/ModuleName/) {
	return "Photo Album";
    }
    elsif (/ModuleInfo/) {
	return "The Photo Album tool allows your website users to browse
through your image library.";
    }
}

1;
