#!/usr/bin/perl
#-----------------------------------------------------------------------
# ctrl-panel.cgi - generate a control panel for a web app
#
# Usage:  /cgi-bin/ctrl-panel.cgi/WEBAPP?options
#
# WEBAPP is the name of an application installed in the Modules area.
#-----------------------------------------------------------------------
#
#   Copyright 2001-2004 Exware Solutions, Inc.  http://www.exware.com
#
#   This file is part of ExSite WebWare (ExSite, for short).
#
#   ExSite is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   ExSite is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with ExSite; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Users requiring warranty coverage and/or support may arrange alternate
#   commercial licensing for ExSite, by contacting Exware Solutions 
#   via the website noted above.
#
#----------------------------------------------------------------------------

use strict;
use ExSite::Config;
use ExSite::PageBuf;
use ExSite::Form;  # use Form if inputting or processing forms
use ExSite::Misc;

use vars qw($db %query);

&exsite_init;
$db = new ExSite::Form;
%query = &DecodeQuery;

# enable page buffering for better redirect control
$config{page_buffering} = 1;

my @path = split /\//, $ENV{PATH_INFO};
shift @path;
my $module = shift @path;
my $p = new ExSite::PageBuf(title=>"$module - $config{site}{name}");

if ($db->authorize) {
    my $stat = eval "require Modules::$module";
    my $app;
    if ($stat) {
	$app = eval "new Modules::$module";
	# look for a control panel
	if ($app) {
	    my $allow = (! $app->ioctl('isRestricted')) || 
		$db->license_control_panel($module);
	    if ($allow) {
		my $panel = $app->ioctl('ControlPanel');
		if (ref $panel eq "CODE") {
		    $p->print( $app->$panel || $@ );
		}
		else {
		    $p->print("<h4>Error executing $module control panel</h4>\n");
		}
	    }
	    else {
		    $p->print("<h4>$module: Permission denied (no license)</h4>\n");
	    }
	}
	else {
	    $p->print("<h4>No control panel found for $module</h4>\n");
	}
    }
    else {
	$p->print("<h4>Failed to start module $module</h4>\n<p>$@</p>\n");
    }
}
else {
    $p->print("<h4>Permission denied.</h4>\n");
}

$p->show;

### END

