#!/usr/bin/perl
#-----------------------------------------------------------------------
# dlg_link.cgi: custom dialog used by HTML editor for adding and editing 
# anchor tags
#-----------------------------------------------------------------------
#
#   Copyright 2001-2004 Exware Solutions, Inc.  http://www.exware.com
#
#   This file is part of ExSite WebWare (ExSite, for short).
#
#   ExSite is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   ExSite is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with ExSite; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Users requiring warranty coverage and/or support may arrange alternate
#   commercial licensing for ExSite, by contacting Exware Solutions 
#   via the website noted above.
#
#----------------------------------------------------------------------------

use strict;
use ExSite::Config;
use ExSite::Misc;
use ExSite::DB;
use myConfig; 

use vars qw(%data $uid $access $OUT $operation $db $js $htop $hbottom);

&exsite_init;
$config{page_buffering} = 0;
%data = &DecodeInput;  # accepts input by post or query
$db = new ExSite::DB;
$access = $db->authorize;
$operation = ($data{url})? "Edit" : "Insert";

if ($access==0) {
	print "Location: login.cgi\n\n";
} elsif ($access<2) {
	&PrintHeader;
	$OUT .= $htop.$hbottom;
	$OUT .= "<p>Access denied.  Webmasters only.</p>";
	$OUT .= &PrintFooter;
	print $OUT;
} else {
	&PrintHeader;
	my @links = &GetSiteLinks;
	$OUT .= $htop.$js.$hbottom;
	$OUT .= &PrintForm(@links);
	$OUT .= &PrintFooter;
	print $OUT;
}

sub GetSiteLinks {
	my (@links,$page_list,$page,$sql,$jscript);
	$jscript = "var pageref = new Array();\n";
#	$sql = "select d.section_id from content_data a, content b, page c, section d where a.content_data_id = $data{data_id} && a.content_id = b.content_id && b.page_id = c.page_id && c.type = 'page' && c.section_id = d.section_id";

	my $sid;
	if ($data{section_id}) {
	    $sid = $data{section_id};
	}
	else {
	    my ($cd);
	    if (exists $data{data_id}){
	    	require ExSite::ContentData;
		$cd = new ExSite::ContentData(id=>$data{data_id});
		$cd->set_context;
		$sid = $cd->id("section");
	    }else{
		require ExSite::Page;	
		$cd = new ExSite::Page(id=>$data{cont_id});
		$cd = $cd->get;
		$sid = $cd->{section_id};
	    }
	}
	#$page = $db->custom_query($sql);
	#$page = $page->[0];
    	$page_list = $db->fetch_match("page",{section_id=>$sid,type=>"page"},'title');
	foreach my $p (@$page_list) {
		$jscript  .= "pageref[\"$p->{filename}\"] = $p->{page_id};\n";
		my $url = "$p->{filename}";
		my $title = "$p->{title}";
#		if ($p->{page_id} == $page->{page_id}) {
#			# put home page top of the list
#			@links = ({url=>$url, text=>$title},@links);
#		} else {
			# the rest go in order of the fetch, which is currently alphabetical
			push @links, {url=>$url, text=>$title};
#		}
	}
	$js = $jscript.$js;
	return @links;
}

sub PrintHeader {
	$htop = "Content-type: text/html

<HTML>
<HEAD>
<TITLE>$operation Link</TITLE>";
if ($ENV{'HTTP_USER_AGENT'} =~ /msie/i){
$htop .= "<style>
	BODY { background-color: buttonface; }
	TD, INPUT, SELECT { font-family: \"MS Sans Serif\"; font-size: xx-small; vertical-align: middle; }
	TABLE.dlg { border:0; }
	.dlg TD { horizontal-align: left; height: 20px; }
	.dlg INPUT { border-size: 2px; }
	INPUT.button { border-top: 1px solid white; border-left: 1px solid white;
		border-bottom: 1px solid black; border-right: 1px solid black;
		font-size: x-small; width: 60px; }
	SELECT { height: 75%; }
</style>";
}else{
$htop .= "<style>
	BODY { background-color: buttonface; }
	TD, INPUT, SELECT { font-family: sans-serif; font-size: small; vertical-align: middle; }
	TABLE.dlg { border:0; }
	.dlg TD { horizontal-align: left; height: 20px; }
	.dlg INPUT { border-size: 2px; }
	INPUT.button_style { 
		border-top: 1px solid white; 
		border-left: 1px solid white;
		border-bottom: 1px solid black; 
		border-right: 1px solid black;
		font-size: x-small; 
		width: 60px;
	}
</style>";
}

$htop .= "<script language=\"JavaScript\">
<!--\n";
$js .= "\tfunction attr(name, value) {
		if (!value || value == \"\") return \"\";
		return ' ' + name + '=\"' + value + '\"';
	}
	function insertLink() {
		window.opener.getLink(document.forms[0].linkURL.value,document.forms[0].linkText.value,document.forms[0].newwindow.checked);
		window.close();
	}
	function cancel() {
		window.returnValue = null;
		window.close();
	}
	function selectMade() {
		var selector = document.forms[0].linkSelect;  
		var choice = selector.options[selector.selectedIndex];
		if (choice.value) {
			document.forms[0].linkURL.value = choice.value;
		}
	}
	function urlsubmit() {
		var key = document.forms[0].linkURL.value;
		if (key){
			if (pageref[key]){
				document.forms[0].linkURL.value = pageref[key];
			}
		}
	}
	function insertsubmit(){
		urlsubmit();
		insertLink();
	}
";
$hbottom .= "\n//-->
</script>
</head>
	<body topmargin=\"0\" leftmargin=\"0\" style=\"border: 0; margin: 0;\" scroll=\"no\">\n";
}

sub PrintFooter {
	return "\n</body></html>";
}

sub PrintForm {
	my (@links) = @_;
	my $spaces = "<img width=\"10\" height=\"10\" border=\"0\" src=\"$config{server}{HTMLpath}/_ExSite$config{server}{imgdir}/null.gif\">";
	my $out = "
<form>
<table border=\"0\" class=\"dlg\" cellpadding=\"0\" cellspacing=\"2\" width=\"100%\" height=\"100%\">
<tr>
 <td colspan=\"3\"><table border=\"0\" width=\"100%\"><tr><td>$operation&nbsp;Link</td><td valign=\"middle\" width=\"90%\"><hr width=\"100%\"></td></tr></table></td>
</tr>
<tr>
 <td width=\"10\">&nbsp;</td>
 <td width=\"70\">Link Text:</td>
 <td valign=\"middle\"><input type=\"text\" name=\"linkText\" value=\"$data{title}\" size=\"50\"></td>
</tr>
<tr>
 <td width=\"10\">&nbsp;</td>
 <td colspan=\"2\">$spaces<br>You may link directly to an internal page, or you can enter an external URL:<br>$spaces</td>
</tr>
<tr>
 <td width=\"10\">&nbsp;</td>
 <td width=\"70\">Select:</td>
 <td valign=\"middle\">
 <SELECT NAME=\"linkSelect\" onChange=\"selectMade()\">";
	if (scalar @links) {
		$out .= "<OPTION value=\"\">==Select Internal Page==</OPTION>\n";
	} else {
		$out .= "<OPTION value=\"\">==No Internal Pages Found==</OPTION>\n";
	}
	foreach my $link (@links) {
		$out .= "<OPTION value=\"$link->{url}\">$link->{text}</OPTION>\n";
	}
	$out .= "
 </SELECT>
 </td>
</tr>\n";
	$out .= "<tr>
 <td width=\"10\">&nbsp;</td>
 <td width=\"70\">URL:</td><td valign=\"middle\"><input type=\"text\" name=\"linkURL\" value=\"$data{url}\" size=\"50\"></td>
</tr>
<tr>
 <td width=\"10\">&nbsp;</td>
 <td colspan=\"2\"><input type=\"checkbox\" name=\"newwindow\"> Open this link in a new window</td>
</tr>
<tr>
 <td>&nbsp;</td>
 <td colspan=\"2\" align=\"right\"><input class=\"button\" type=\"button\" value=\"Submit\" title=\"Submit\" onclick=\"insertsubmit()\">
<input class=\"button\" type=\"button\" value=\"Cancel\" title=\"Cancel Dialog\" onclick=\"cancel()\"></td>
</tr>
</table>
</form>";
	return $out;
}
### END
